;; Generated package description from preview-tailor.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "preview-tailor" "0.2.1.0.20251201.82034" "Tailor AUCTeX preview scale to monitor/text scale" '((emacs "29.1") (auctex "0")) :commit "731d92247aab0a51c208d0fe196db3dec0d1b2e9" :authors '(("Paul D. Nelson" . "nelson.paul.david@gmail.com")) :maintainer '("Paul D. Nelson" . "nelson.paul.david@gmail.com") :keywords '("tex" "multimedia") :url "https://github.com/ultronozm/preview-tailor.el")
